@@ -27,7 +27,7 @@ dependencies using raw pip. The virtual environment is not created, but one can
 issue `python3 -m venv venv/ && . venv/bin/activate` to create one.
 """
 
-__version__ = "1.0.3"
+__version__ = "1.0.4"
 __author__ = "Fridolin Pokorny <fridex.devel@gmail.com>"
 __title__ = "micropipenv"
 
@@ -328,6 +328,12 @@ def install_pipenv(
 
             package_entry_str = _get_package_entry_str(package_name, info)
             for index_config_str in _iter_index_entry_str(sections, info):
+                # We are opening the tmp_file for the second time here.
+                # The purpose of this is to make sure that the content is always
+                # flushed from buffers and that we start from the beggining
+                # of the file every time. All of that to make sure that there is
+                # only one package written in the tmp_file and pip is able to
+                # read the package name from the file.
                 with open(tmp_file.name, "w") as f:
                     f.write(index_config_str)
                     f.write(package_entry_str)
@@ -354,6 +360,7 @@ def install_pipenv(
                 to_install.append({"package_name": package_name, "info": info, "error": had_error + 1})
 
     finally:
+        tmp_file.close()
         os.remove(tmp_file.name)
 
 
